@@ -1,4 +1,8 @@
+import sys
+
+from alliancepy.cache import Cache
 from alliancepy.team import Team
+from alliancepy.http import request
 import logging
 
 # MIT License
@@ -34,10 +38,13 @@ class Client:
 
     Args:
         api_key (str): Your TOA API key. This is required, otherwise you will not be able to access the database.
-        application_name (str): The name of your application. It can just be the name of your script.
+        application_name (str): The name of your application. It can just be the name of your script. Defaults to \
+        ``sys.argv[0]``
     """
 
-    def __init__(self, api_key: str, application_name: str):
+    def __init__(self, api_key: str, application_name: str = None):
+        application_name = application_name or sys.argv[0]
+        cache = Cache()
         self._headers = {
             "content-type": "application/json",
             "x-toa-key": api_key,
@@ -55,3 +62,16 @@ class Client:
         """
         logger.info(f"Got request for team with team number of {team_number}")
         return Team(team_number=team_number, headers=self._headers)
+
+    @property
+    def api_version(self):
+        """The version of the API that is currently in use.
+
+        :rtype: int
+        """
+        data = request("/", headers=self._headers)
+        return data["version"]
+
+    def clear_cache(self):
+        """Clears the cache. This is useful for long-running applications when the cache gets too big."""
+        request("clear", headers=self._headers)
