@@ -1,3 +1,5 @@
+from .async_executor import get_loop
+from alliancepy.cache import Cache
 import aiohttp
 import json
 import logging
@@ -29,30 +31,37 @@ logger = logging.getLogger(__name__)
 
 
 async def request(target: str, headers: dict):
-    session = aiohttp.ClientSession(headers=headers)
-    url = f"https://theorangealliance.org/api{target}"
-    task = asyncio.ensure_future(session.get(url, headers=headers))
-    resp = await task
-    if resp.status != 200:
-        if resp.status == 429:
-            rhead = {key.lower(): value for key, value in resp.headers.items()}
-            seconds = int(rhead["retry-after"])
-            logger.info(f"Status code was 429, sleeping for {seconds} seconds")
-            await asyncio.sleep(seconds)
-            task = asyncio.ensure_future(request(target, headers))
-            return await task
-        logger.info(f"Status code was not 200 ({resp.status}), attempting to gather error message")
-        try:
-            data = json.loads(await resp.text())
-        except json.decoder.JSONDecodeError:
-            raise WebException(await resp.text())
-        else:
-            raise WebException(data["_message"])
-    data = json.loads(await resp.text())
-    logger.info(f"Request succsessful, returning response to origin")
-    await session.close()
+    with Cache() as cache:
+        if target in cache.keys():
+            return cache.get(target)
+        session = aiohttp.ClientSession(headers=headers)
+        url = f"https://theorangealliance.org/api{target}"
+        task = get_loop().create_task(session.get(url))
+        resp = await task
+        if resp.status != 200:
+            if resp.status == 429:
+                rhead = {key.lower(): value for key, value in resp.headers.items()}
+                seconds = int(rhead["retry-after"])
+                logger.info(f"Status code was 429, sleeping for {seconds} seconds")
+                await session.close()
+                await asyncio.sleep(seconds)
+                logger.info("Done sleeping, attempting request again")
+                return await request(target, headers)
+            logger.info(
+                f"Status code was not 200 ({resp.status}), attempting to gather error message"
+            )
+            try:
+                data = json.loads(await resp.text())
+            except json.decoder.JSONDecodeError:
+                raise WebException(await resp.text())
+            else:
+                raise WebException(data["_message"])
+        data = json.loads(await resp.text())
+        logger.info(f"Request succsessful, returning response to origin")
+        await session.close()
 
-    return data
+        cache.add(target, data)
+        return data
 
 
 class WebException(Exception):
