@@ -1,5 +1,6 @@
 from .async_http import request
 from .async_event import Event
+from .async_executor import get_loop
 from alliancepy.season import Season
 import asyncio
 from concurrent.futures import ThreadPoolExecutor
@@ -60,7 +61,7 @@ class Team:
     def __init__(self, team_number, headers: dict):
         self._team_number = team_number
         self._headers = headers
-        self._loop = asyncio.get_event_loop()
+        self._loop = get_loop()
         team = self._loop.run_until_complete(
             request(target=f"/team/{team_number}", headers=headers)
         )
@@ -93,26 +94,45 @@ class Team:
         events = await request(
             f"/team/{self._team_number}/events/{season}", headers=self._headers
         )
+        q = asyncio.Queue()
+        headers = self._headers
 
-        def _parse_events(ev=events, ed=None):
-            ed = ed or edict
-            for event in ev:
-                e = Event(event_key=event["event_key"], headers=self._headers)
-                event_key = event["event_key"]
+        async def worker():
+            while True:
+                event_key = await q.get()
+                e = Event(event_key=event_key, headers=headers)
                 raw_key = str(e.name)
                 key = raw_key.replace(" ", "_")
                 key = key.lower()
-                if key in ed:
+                if key in edict:
                     raw_key_right = re.sub(r"\d{4}-\w+-", "", event_key)
                     raw_key_right = raw_key_right.lower()
                     key = f"{key}_{raw_key_right}"
-                ed[key] = e
+                edict[key] = e
+                q.task_done()
 
-            return ed
+        logger.info("Sending tasks to queue")
+        for event in events:
+            await q.put(event["event_key"])
 
-        loop = asyncio.get_event_loop_policy().new_event_loop()
-        future = loop.run_in_executor(ThreadPoolExecutor(), _parse_events)
-        return loop.run_until_complete(future)
+        tasks = []
+        logger.info("Creating three workers to process the queue concurrently")
+        for _ in range(3):
+            task = get_loop().create_task(worker())
+            tasks.append(task)
+
+        logger.info("Processing units in queue")
+        await q.join()
+        logger.info("Done proccessing, killing workers")
+
+        for task in tasks:
+            task.cancel()
+
+        logger.info("Waiting for workers to be killed")
+        await asyncio.gather(*tasks, return_exceptions=True)
+
+        logger.info("All workers killed, finishing up")
+        return edict
 
     async def _wlt(self):
         logger.info("Fetching WLT data")
@@ -123,37 +143,34 @@ class Team:
         self._losses = data[0]["losses"]
         self._ties = data[0]["ties"]
 
-    @property
-    def wins(self):
+    async def wins(self):
         """
         The total amount of times the team has won a match.
 
         :return: The number of wins.
         :rtype: int
         """
-        self._loop.run_until_complete(self._wlt())
+        await self._wlt()
         return self._wins
 
-    @property
-    def losses(self):
+    async def losses(self):
         """
         The total amount of times the team has lost a match.
 
-        :return: The number of wins.
+        :return: The number of losses.
         :rtype: int
         """
-        self._loop.run_until_complete(self._wlt())
+        await self._wlt()
         return self._losses
 
-    @property
-    def ties(self):
+    async def ties(self):
         """
-        The total amount of times the team has tied in a match.
+        The total amount of times the team has tied in a match a match.
 
-        :return: The number of wins.
+        :return: The number of ties.
         :rtype: int
         """
-        self._loop.run_until_complete(self._wlt())
+        await self._wlt()
         return self._ties
 
     async def _rankings(self, season: Season):
