@@ -1,4 +1,6 @@
 from alliancepy.http import request
+import logging
+
 
 # MIT License
 #
@@ -22,6 +24,8 @@ from alliancepy.http import request
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+logger = logging.getLogger(__name__)
+
 
 class Match:
     """
@@ -43,6 +47,7 @@ class Match:
         self.randomization = int(details[0]["randomization"])
         self.red = Alliance("red", self._match_key, details, self._headers)
         self.blue = Alliance("blue", self._match_key, details, self._headers)
+        logger.info(f"Initialized Match object with match key of {self._match_key}")
 
     def __str__(self):
         return f"<Match ({self._match_key})>"
@@ -85,6 +90,9 @@ class Alliance:
         self._headers = headers
         self.robot_1 = Robot(self._alliance, 1, match_key, details, self._headers)
         self.robot_2 = Robot(self._alliance, 2, match_key, details, self._headers)
+        logger.info(
+            f"Initialized Alliance object with alliance name of {self._alliance}"
+        )
 
     def __str__(self):
         return f"<Alliance ({self._alliance})>"
@@ -167,6 +175,9 @@ class Robot:
         self._match_key = match_key
         self._details = details[0]
         self._headers = headers
+        logger.info(
+            f"Initialized Robot object with alliance {self._alliance} and robot number of {self._robot_number}"
+        )
 
     @property
     def parked_skybridge(self):
@@ -207,10 +218,18 @@ class Robot:
         :return: The team's team number as an integer
         :rtype: int
         """
-        participants = request(
-            f"/match/{self._match_key}/participants", headers=self._headers
+        match = request(f"/match/{self._match_key}", headers=self._headers)
+        participants = list(
+            filter(lambda p: p["station_status"] == 1, match[0]["participants"])
         )
-        for part in participants:
-            station = str(part["station"])
-            if int(station[1]) == self._robot_number:
-                return int(part["team_key"])
+        if self._alliance == "red" and self._robot_number == 1:
+            raw = participants[0]["team_key"]
+        elif self._alliance == "red" and self._robot_number == 2:
+            raw = participants[1]["team_key"]
+        elif self._alliance == "blue" and self._robot_number == 1:
+            raw = participants[2]["team_key"]
+        elif self._alliance == "blue" and self._robot_number == 2:
+            raw = participants[3]["team_key"]
+        else:
+            raise ValueError("Something went wrong, please try again")
+        return int(raw)
